#
# spec file for package libaacs
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname %{name}0
Name:           libaacs
Version:        0.9.0
Release:        lp150.1.4
Summary:        Open implentation of AACS specification
License:        LGPL-2.1+
Group:          System/Libraries
Url:            http://www.videolan.org/developers/libaacs.html
Source:         ftp://ftp.videolan.org/pub/videolan/libaacs/%{version}/libaacs-%{version}.tar.bz2
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libgcrypt-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libaacs is a research project to implement the Advanced Access Content System specification.
This research project provides, through an open-source library, a way to understand how the AACS works.

%package -n %{libname}
Summary:        Open implentation of AACS specification
Group:          System/Libraries

%description -n %{libname}
libaacs is a research project to implement the Advanced Access Content System specification.
This research project provides, through an open-source library, a way to understand how the AACS works.

%package devel
Summary:        Open implentation of AACS specification - Development files
Group:          Development/Languages/C and C++
Requires:       libaacs0 = %{version}

%description devel
libaacs is a research project to implement the Advanced Access Content System specification.
This research project provides, through an open-source library, a way to understand how the AACS works.

%prep
%setup -q

%build
autoreconf -fvi
%configure \
    --disable-static \
    --disable-silent-rules
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-, root, root)
%doc COPYING
%{_bindir}/aacs_info
%{_libdir}/libaacs.so.0
%{_libdir}/libaacs.so.0.*

%files devel
%defattr(-, root, root)
%{_libdir}/libaacs.so
%{_libdir}/pkgconfig/libaacs.pc
%{_includedir}/%{name}/

%changelog
* Tue May 16 2017 joerg.lorenzen@ki.tng.de
- update to 0.9.0
  * Add aacs_decrypt_bus().
  * Add aacs_get_bdj_root_cert_hash().
  * Add aacs_get_content_cert_id().
  * Add support for unencrypted content in AACS-enabled discs.
  * Improve error resilience.
  * Improve support for broken discs (use on-disc backup files).
  * Verify content certificate signature.
  * Load and merge multiple KEYDB.cfg files.
  * Fix build with gcrypt < 1.6.0.
  * Fix possible crash (debug log output that includes discid).
  * Fix config file path issues in Windows (non-ASCII paths).
  * Fix dll exports in Windows.
  * Fix resource leaks.
  * Reduced memory footprint.
* Wed Feb 22 2017 scarabeus@opensuse.org
- Cleanup a bit with spec-cleaner
- Remove sle11 support
- Drop no longer needed patch libaacs-0.6.0-bison-2.3-compatibility.patch
* Sun Mar 15 2015 joerg.lorenzen@ki.tng.de
- update to 0.8.1
  * Accept NULL mount / device path when application handles file system access.
  * Fix FreeBSD build.
  * Do not require pthread with gcrypt >= 1.6.0.
* Tue Jan 27 2015 joerg.lorenzen@ki.tng.de
- update to 0.8.0
  * Add improved file system interface
  * Support opening raw devices
  * Reduce log level of failed PMSN query
  * Optimizations
* Wed Dec 17 2014 joerg.lorenzen@ki.tng.de
- update to 0.7.1
  * Add support for gcrypt 1.6.0.
  * Do not retrieve MKB using MMC commands during AACS-Auth.
* Fri Apr 25 2014 dnh@opensuse.org
- update to 0.7.0
  * Add aacs_get_device_binding_id() and aacs_get_device_nonce().
  * Add aacs_get_mk().
  * Add support for bus encryption.
  * Add support for device keys.
  * Add support for internal keys.
  * Fix reading PMSN.
  * Fix reporting AACS version from AACS drive feature.
  * Calculate bus key and use it to verify message authentication codes.
  * Do not fail if VID is known but config file does not exist.
  * Improve validating keys in KEYDB.cfg.
  * Update KEYDB.cfg format (still backwards compatible):
  * Host nonce and host key point are optional.
  * Add device key UV values and masks.
  * Build system updates.
  * Drop support for compile-time PATCHED_DRIVE flag.
* Sat Mar 16 2013 obs@botter.cc
- update to 0.6.0
  * Added reading of PMSN (Pre-recorded Media Serial Number)
  * Fix resource leak
  * Use proper paths to search for keydb and friends on Darwin.
  * Build fixes and improvements
- 0.5.0
  * Support for Mac OS X using IOKit
  * Fix AACS detection failure in some Win32 systems
- 0.4.0
  * Added aacs_open2() and error codes
  * Renamed libaacs_test to aacs_info
  * Added aacs_get_mkb_version()
  * Fixed memory leaks
  * Fixed buffer overflow
  * Added revocation list caching
  * Check host certificates against latest seen revocation list
- 0.3.1
  * Added configure option for libgcrypt prefix
  * Fixed building Win32 DLL
  * Fixed segfault when mount point path can't be resolved
  * Do not export internal symbols from generated parser/lexer
  * Do not distribute generated parser files
  * Check for libgpg-error. Link against it when needed.
  * Distribute README.txt
  * Added ChangeLog
* Sat Dec  3 2011 pascal.bleser@opensuse.org
- update to 0.3.0 (first proper release)
* Wed Nov 16 2011 dimstar@opensuse.org
- Initial package, git snapshot 2011-11-16.
